#! /usr/bin/env bash

alias @=bluer_ai

alias @T=bluer_ai_terraform
alias @terraform=bluer_ai_terraform

alias @act=bluer_ai_perform_action
alias @action=bluer_ai_perform_action
alias @perform_action=bluer_ai_perform_action

alias @build_README=bluer_ai_build_README

alias @conda=bluer_ai_conda

alias @create_video=abcli_create_video

alias @docker=bluer_ai_docker

alias @ffmpeg=abcli_ffmpeg

alias @git=bluer_ai_git
alias @git++="bluer_ai_git increment_version"

alias @gpu=bluer_ai_gpu

alias @init=bluer_ai_init

alias @latex=bluer_ai_latex

alias @mac='if [ "$abcli_is_mac" == true ]; then'
alias @.='fi'

alias @pip=abcli_pip

alias @plugins=bluer_ai_plugins

alias @pypi=bluer_ai_pypi

alias @random=abcli_string_random

alias @seed=bluer_ai_seed

alias @session=bluer_ai_session

alias @ssm=bluer_ai_ssm

alias @storage=bluer_ai_storage

alias @version="bluer_ai version"

alias @wifi=abcli_wifi
